from typing import Dict, List, Optional, Tuple, Union, Any
from typing_extensions import Annotated
from pydantic import StrictFloat, StrictStr, StrictInt, StrictBytes, Field, validate_call

from smallestai.atoms.configuration import Configuration
from smallestai.atoms.api.agents_api import AgentsApi
from smallestai.atoms.api.knowledge_base_api import KnowledgeBaseApi
from smallestai.atoms.api.calls_api import CallsApi
from smallestai.atoms.models.create_agent_request import CreateAgentRequest
from smallestai.atoms.models.agent_id_patch_request import AgentIdPatchRequest
from smallestai.atoms.models.knowledgebase_post_request import KnowledgebasePostRequest
from smallestai.atoms.models.knowledgebase_id_items_upload_text_post_request import KnowledgebaseIdItemsUploadTextPostRequest
from smallestai.atoms.models.conversation_outbound_post_request import ConversationOutboundPostRequest
from smallestai.atoms.api_client import ApiClient
from smallestai.atoms.api.user_api import UserApi
from smallestai.atoms.api.organization_api import OrganizationApi
from smallestai.atoms.models.user_get200_response import UserGet200Response
from smallestai.atoms.models.organization_get200_response import OrganizationGet200Response
from smallestai.atoms.api.campaigns_api import CampaignsApi
from smallestai.atoms.models.campaign_post_request import CampaignPostRequest
from smallestai.atoms.models.campaign_get_request import CampaignGetRequest
from smallestai.atoms.api.agent_templates_api import AgentTemplatesApi
from smallestai.atoms.models.create_agent_from_template_request import CreateAgentFromTemplateRequest
from smallestai.atoms.api.logs_api import LogsApi
from smallestai.atoms.models.conversation_id_get200_response import ConversationIdGet200Response

class AtomsClient:
    def __init__(self, configuration=None) -> None:
        if configuration is None:
            configuration = Configuration.get_default()
        
        self.api_client = ApiClient(configuration)
        self.agents_api = AgentsApi(self.api_client)
        self.knowledge_base_api = KnowledgeBaseApi(self.api_client)
        self.calls_api = CallsApi(self.api_client)
        self.user_api = UserApi(self.api_client)
        self.organization_api = OrganizationApi(self.api_client)
        self.campaigns_api = CampaignsApi(self.api_client)
        self.agent_templates_api = AgentTemplatesApi(self.api_client)
        self.logs_api = LogsApi(self.api_client)

    # Agent Methods
    @validate_call
    def create_agent(
        self,
        create_agent_request: CreateAgentRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agents_api.agent_post(
            create_agent_request=create_agent_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def delete_agent(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agents_api.agent_id_delete(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_agent_by_id(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agents_api.agent_id_get(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_agents(
        self,
        page: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agents_api.agent_get(
            page=page,
            offset=offset,
            search=search,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def update_agent(
        self,
        id: StrictStr,
        agent_id_patch_request: AgentIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agents_api.agent_id_patch(
            id=id,
            agent_id_patch_request=agent_id_patch_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_agent_workflow(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agents_api.agent_id_workflow_get(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    # Knowledge Base Methods
    @validate_call
    def create_knowledge_base(
        self,
        knowledgebase_post_request: KnowledgebasePostRequest,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_post(
            knowledgebase_post_request=knowledgebase_post_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def delete_knowledge_base(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_id_delete(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_knowledge_base_by_id(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_id_get(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_knowledge_bases(
        self,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_get(
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def upload_text_to_knowledge_base(
        self,
        id: StrictStr,
        knowledgebase_id_items_upload_text_post_request: KnowledgebaseIdItemsUploadTextPostRequest,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_id_items_upload_text_post(
            id=id,
            knowledgebase_id_items_upload_text_post_request=knowledgebase_id_items_upload_text_post_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def upload_media_to_knowledge_base(
        self,
        id: StrictStr,
        media: Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]],
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_id_items_upload_media_post(
            id=id,
            media=media,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_knowledge_base_items(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_id_items_get(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def delete_knowledge_base_item(
        self,
        knowledge_base_id: StrictStr,
        knowledge_base_item_id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.knowledge_base_api.knowledgebase_knowledge_base_id_items_knowledge_base_item_id_delete(
            knowledge_base_id=knowledge_base_id,
            knowledge_base_item_id=knowledge_base_item_id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    # Calls Methods
    @validate_call
    def start_outbound_call(
        self,
        conversation_outbound_post_request: ConversationOutboundPostRequest,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.calls_api.conversation_outbound_post(
            conversation_outbound_post_request=conversation_outbound_post_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    # User Methods
    @validate_call
    def get_current_user(
        self,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserGet200Response:
        return self.user_api.user_get(
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    # Organization Methods
    @validate_call
    def get_organization(
        self,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OrganizationGet200Response:
        return self.organization_api.organization_get(
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    # Campaign Methods
    @validate_call
    def create_campaign(
        self,
        campaign_post_request: CampaignPostRequest,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.campaigns_api.campaign_post(
            campaign_post_request=campaign_post_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def delete_campaign(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.campaigns_api.campaign_id_delete(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_campaign_by_id(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.campaigns_api.campaign_id_get(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def get_campaigns(
        self,
        campaign_get_request: CampaignGetRequest,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.campaigns_api.campaign_get(
            campaign_get_request=campaign_get_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def start_campaign(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.campaigns_api.campaign_id_start_post(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def pause_campaign(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.campaigns_api.campaign_id_pause_post(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    # Agent Template Methods
    @validate_call
    def get_agent_templates(
        self,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agent_templates_api.agent_template_get(
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    @validate_call
    def create_agent_from_template(
        self,
        create_agent_from_template_request: CreateAgentFromTemplateRequest,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ):
        return self.agent_templates_api.agent_from_template_post(
            create_agent_from_template_request=create_agent_from_template_request,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

    # Logs Methods
    @validate_call
    def get_conversation_logs(
        self,
        id: StrictStr,
        _request_timeout: Union[None, Annotated[StrictFloat, Field(gt=0)], Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]]] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ConversationIdGet200Response:
        return self.logs_api.conversation_id_get(
            id=id,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )



"""
SmallestAI Python SDK

This package provides access to both the Atoms API (agent management)
and Waves API components.
"""

from smallestai.atoms import (
    AgentTemplatesApi,
    AgentsApi,
    CallsApi,
    CampaignsApi,
    KnowledgeBaseApi,
    LogsApi,
    OrganizationApi,
    UserApi,
    ApiResponse,
    ApiClient,
    Configuration,
    OpenApiException,
    ApiTypeError,
    ApiValueError,
    ApiKeyError,
    ApiAttributeError,
    ApiException,
    AgentDTO,
    AgentDTOLanguage,
    AgentDTOSynthesizer,
    AgentDTOSynthesizerVoiceConfig,
    BadRequestErrorResponse,
    AgentFromTemplatePost200Response,
    CreateAgentFromTemplateRequest,
    CreateAgentRequest,
    CreateAgentRequestLanguage,
    CreateAgentRequestLanguageSynthesizer,
    CreateAgentRequestLanguageSynthesizerVoiceConfig,
    CampaignPost201Response,
    CampaignPostRequest,
    CampaignGetRequest,
    AgentIdDelete200Response,
    AgentIdGet200Response,
    AgentTemplateGet200Response,
    AgentTemplateGet200ResponseDataInner,
    AgentGet200Response,
    CampaignIdGet200Response,
    CampaignGet200Response,
    ConversationIdGet200Response,
    ConversationIdGet200ResponseData,
    UserGet200Response,
    UserGet200ResponseData,
    KnowledgebaseIdGet200Response,
    KnowledgebasePost201Response,
    KnowledgebasePostRequest,
    KnowledgebaseIdItemsUploadTextPostRequest,
    OrganizationGet200Response,
    OrganizationGet200ResponseData,
    OrganizationGet200ResponseDataMembersInner,
    OrganizationGet200ResponseDataSubscription,
    InternalServerErrorResponse,
    ConversationOutboundPost200Response,
    ConversationOutboundPost200ResponseData,
    ConversationOutboundPostRequest,
    UnauthorizedErrorReponse,
    AgentIdPatch200Response,
    AgentIdPatchRequest,
    AgentIdPatchRequestLanguage,
    AgentIdPatchRequestSynthesizer,
    AgentIdPatchRequestSynthesizerVoiceConfig,
    AgentIdPatchRequestSynthesizerVoiceConfigOneOf,
    AgentIdPatchRequestSynthesizerVoiceConfigOneOf1,
    AtomsClient
)

from smallestai.waves import (
    WavesClient,
    AsyncWavesClient,
    WavesStreamingTTS
)

from smallestai.atoms import __all__ as atoms_all
from smallestai.waves import __all__ as waves_all

__all__ = atoms_all + waves_all

__version__ = "4.0.1"


# coding: utf-8

# flake8: noqa

"""
    Agent Management API

    API for managing agents, their templates, and call logs

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import apis into sdk package
from smallestai.atoms.api.agent_templates_api import AgentTemplatesApi
from smallestai.atoms.api.agents_api import AgentsApi
from smallestai.atoms.api.calls_api import CallsApi
from smallestai.atoms.api.campaigns_api import CampaignsApi
from smallestai.atoms.api.knowledge_base_api import KnowledgeBaseApi
from smallestai.atoms.api.logs_api import LogsApi
from smallestai.atoms.api.organization_api import OrganizationApi
from smallestai.atoms.api.user_api import UserApi

# import ApiClient
from smallestai.atoms.api_response import ApiResponse
from smallestai.atoms.api_client import ApiClient
from smallestai.atoms.configuration import Configuration
from smallestai.atoms.exceptions import OpenApiException
from smallestai.atoms.exceptions import ApiTypeError
from smallestai.atoms.exceptions import ApiValueError
from smallestai.atoms.exceptions import ApiKeyError
from smallestai.atoms.exceptions import ApiAttributeError
from smallestai.atoms.exceptions import ApiException
from smallestai.atoms.atoms_client import AtomsClient

# import models into sdk package
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_delete200_response import AgentAgentIdWebhookSubscriptionsDelete200Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_get200_response import AgentAgentIdWebhookSubscriptionsGet200Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_get404_response import AgentAgentIdWebhookSubscriptionsGet404Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post201_response import AgentAgentIdWebhookSubscriptionsPost201Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post400_response import AgentAgentIdWebhookSubscriptionsPost400Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post_request import AgentAgentIdWebhookSubscriptionsPostRequest
from smallestai.atoms.models.agent_dto import AgentDTO
from smallestai.atoms.models.agent_dto_language import AgentDTOLanguage
from smallestai.atoms.models.agent_dto_synthesizer import AgentDTOSynthesizer
from smallestai.atoms.models.agent_dto_synthesizer_voice_config import AgentDTOSynthesizerVoiceConfig
from smallestai.atoms.models.agent_from_template_post200_response import AgentFromTemplatePost200Response
from smallestai.atoms.models.agent_get200_response import AgentGet200Response
from smallestai.atoms.models.agent_id_delete200_response import AgentIdDelete200Response
from smallestai.atoms.models.agent_id_get200_response import AgentIdGet200Response
from smallestai.atoms.models.agent_id_patch200_response import AgentIdPatch200Response
from smallestai.atoms.models.agent_id_patch_request import AgentIdPatchRequest
from smallestai.atoms.models.agent_id_patch_request_language import AgentIdPatchRequestLanguage
from smallestai.atoms.models.agent_id_patch_request_synthesizer import AgentIdPatchRequestSynthesizer
from smallestai.atoms.models.agent_id_patch_request_synthesizer_voice_config import AgentIdPatchRequestSynthesizerVoiceConfig
from smallestai.atoms.models.agent_id_patch_request_synthesizer_voice_config_one_of import AgentIdPatchRequestSynthesizerVoiceConfigOneOf
from smallestai.atoms.models.agent_id_patch_request_synthesizer_voice_config_one_of1 import AgentIdPatchRequestSynthesizerVoiceConfigOneOf1
from smallestai.atoms.models.agent_id_workflow_get200_response import AgentIdWorkflowGet200Response
from smallestai.atoms.models.agent_id_workflow_get200_response_data import AgentIdWorkflowGet200ResponseData
from smallestai.atoms.models.agent_id_workflow_get200_response_data_edges_inner import AgentIdWorkflowGet200ResponseDataEdgesInner
from smallestai.atoms.models.agent_id_workflow_get200_response_data_edges_inner_data import AgentIdWorkflowGet200ResponseDataEdgesInnerData
from smallestai.atoms.models.agent_id_workflow_get200_response_data_edges_inner_marker_end import AgentIdWorkflowGet200ResponseDataEdgesInnerMarkerEnd
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner import AgentIdWorkflowGet200ResponseDataNodesInner
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_data import AgentIdWorkflowGet200ResponseDataNodesInnerData
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_data_variables import AgentIdWorkflowGet200ResponseDataNodesInnerDataVariables
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_data_variables_data_inner import AgentIdWorkflowGet200ResponseDataNodesInnerDataVariablesDataInner
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_position import AgentIdWorkflowGet200ResponseDataNodesInnerPosition
from smallestai.atoms.models.agent_id_workflow_get404_response import AgentIdWorkflowGet404Response
from smallestai.atoms.models.agent_template_get200_response import AgentTemplateGet200Response
from smallestai.atoms.models.agent_template_get200_response_data_inner import AgentTemplateGet200ResponseDataInner
from smallestai.atoms.models.api_response import ApiResponse
from smallestai.atoms.models.audience_get200_response import AudienceGet200Response
from smallestai.atoms.models.audience_get200_response_data_inner import AudienceGet200ResponseDataInner
from smallestai.atoms.models.audience_id_delete200_response import AudienceIdDelete200Response
from smallestai.atoms.models.audience_id_delete400_response import AudienceIdDelete400Response
from smallestai.atoms.models.audience_id_get200_response import AudienceIdGet200Response
from smallestai.atoms.models.audience_id_get400_response import AudienceIdGet400Response
from smallestai.atoms.models.audience_id_get403_response import AudienceIdGet403Response
from smallestai.atoms.models.audience_id_get404_response import AudienceIdGet404Response
from smallestai.atoms.models.audience_id_members_delete200_response import AudienceIdMembersDelete200Response
from smallestai.atoms.models.audience_id_members_delete200_response_data import AudienceIdMembersDelete200ResponseData
from smallestai.atoms.models.audience_id_members_delete_request import AudienceIdMembersDeleteRequest
from smallestai.atoms.models.audience_id_members_get200_response import AudienceIdMembersGet200Response
from smallestai.atoms.models.audience_id_members_get200_response_data import AudienceIdMembersGet200ResponseData
from smallestai.atoms.models.audience_id_members_get200_response_data_members_inner import AudienceIdMembersGet200ResponseDataMembersInner
from smallestai.atoms.models.audience_id_members_get400_response import AudienceIdMembersGet400Response
from smallestai.atoms.models.audience_id_members_get500_response import AudienceIdMembersGet500Response
from smallestai.atoms.models.audience_id_members_post200_response import AudienceIdMembersPost200Response
from smallestai.atoms.models.audience_id_members_post200_response_data_inner import AudienceIdMembersPost200ResponseDataInner
from smallestai.atoms.models.audience_id_members_post200_response_data_inner_data import AudienceIdMembersPost200ResponseDataInnerData
from smallestai.atoms.models.audience_id_members_post400_response import AudienceIdMembersPost400Response
from smallestai.atoms.models.audience_id_members_post403_response import AudienceIdMembersPost403Response
from smallestai.atoms.models.audience_id_members_post_request import AudienceIdMembersPostRequest
from smallestai.atoms.models.audience_id_members_search_get200_response import AudienceIdMembersSearchGet200Response
from smallestai.atoms.models.audience_id_members_search_get200_response_data import AudienceIdMembersSearchGet200ResponseData
from smallestai.atoms.models.audience_id_members_search_get200_response_data_search_info import AudienceIdMembersSearchGet200ResponseDataSearchInfo
from smallestai.atoms.models.audience_id_members_search_get400_response import AudienceIdMembersSearchGet400Response
from smallestai.atoms.models.audience_id_members_search_get500_response import AudienceIdMembersSearchGet500Response
from smallestai.atoms.models.audience_post200_response import AudiencePost200Response
from smallestai.atoms.models.audience_post200_response_data import AudiencePost200ResponseData
from smallestai.atoms.models.audience_post400_response import AudiencePost400Response
from smallestai.atoms.models.bad_request_error_response import BadRequestErrorResponse
from smallestai.atoms.models.campaign_get200_response import CampaignGet200Response
from smallestai.atoms.models.campaign_get200_response_data import CampaignGet200ResponseData
from smallestai.atoms.models.campaign_get_request import CampaignGetRequest
from smallestai.atoms.models.campaign_id_get200_response import CampaignIdGet200Response
from smallestai.atoms.models.campaign_post201_response import CampaignPost201Response
from smallestai.atoms.models.campaign_post_request import CampaignPostRequest
from smallestai.atoms.models.conversation_id_get200_response import ConversationIdGet200Response
from smallestai.atoms.models.conversation_id_get200_response_data import ConversationIdGet200ResponseData
from smallestai.atoms.models.conversation_outbound_post200_response import ConversationOutboundPost200Response
from smallestai.atoms.models.conversation_outbound_post200_response_data import ConversationOutboundPost200ResponseData
from smallestai.atoms.models.conversation_outbound_post_request import ConversationOutboundPostRequest
from smallestai.atoms.models.create_agent_from_template_request import CreateAgentFromTemplateRequest
from smallestai.atoms.models.create_agent_request import CreateAgentRequest
from smallestai.atoms.models.create_agent_request_language import CreateAgentRequestLanguage
from smallestai.atoms.models.create_agent_request_language_synthesizer import CreateAgentRequestLanguageSynthesizer
from smallestai.atoms.models.create_agent_request_language_synthesizer_voice_config import CreateAgentRequestLanguageSynthesizerVoiceConfig
from smallestai.atoms.models.internal_server_error_response import InternalServerErrorResponse
from smallestai.atoms.models.knowledge_base import KnowledgeBase
from smallestai.atoms.models.knowledge_base_item import KnowledgeBaseItem
from smallestai.atoms.models.knowledgebase_get200_response import KnowledgebaseGet200Response
from smallestai.atoms.models.knowledgebase_id_get200_response import KnowledgebaseIdGet200Response
from smallestai.atoms.models.knowledgebase_id_items_get200_response import KnowledgebaseIdItemsGet200Response
from smallestai.atoms.models.knowledgebase_id_items_upload_text_post_request import KnowledgebaseIdItemsUploadTextPostRequest
from smallestai.atoms.models.knowledgebase_post201_response import KnowledgebasePost201Response
from smallestai.atoms.models.knowledgebase_post_request import KnowledgebasePostRequest
from smallestai.atoms.models.organization_get200_response import OrganizationGet200Response
from smallestai.atoms.models.organization_get200_response_data import OrganizationGet200ResponseData
from smallestai.atoms.models.organization_get200_response_data_members_inner import OrganizationGet200ResponseDataMembersInner
from smallestai.atoms.models.organization_get200_response_data_subscription import OrganizationGet200ResponseDataSubscription
from smallestai.atoms.models.product_phone_numbers_get200_response import ProductPhoneNumbersGet200Response
from smallestai.atoms.models.product_phone_numbers_get200_response_data_inner import ProductPhoneNumbersGet200ResponseDataInner
from smallestai.atoms.models.product_phone_numbers_get200_response_data_inner_attributes import ProductPhoneNumbersGet200ResponseDataInnerAttributes
from smallestai.atoms.models.unauthorized_error_reponse import UnauthorizedErrorReponse
from smallestai.atoms.models.user_get200_response import UserGet200Response
from smallestai.atoms.models.user_get200_response_data import UserGet200ResponseData
from smallestai.atoms.models.webhook import Webhook
from smallestai.atoms.models.webhook_agent import WebhookAgent
from smallestai.atoms.models.webhook_event import WebhookEvent
from smallestai.atoms.models.webhook_get200_response import WebhookGet200Response
from smallestai.atoms.models.webhook_get200_response_data import WebhookGet200ResponseData
from smallestai.atoms.models.webhook_id_delete404_response import WebhookIdDelete404Response
from smallestai.atoms.models.webhook_post201_response import WebhookPost201Response
from smallestai.atoms.models.webhook_post_request import WebhookPostRequest
from smallestai.atoms.models.webhook_post_request_events_inner import WebhookPostRequestEventsInner
from smallestai.atoms.models.webhook_subscription import WebhookSubscription
from smallestai.atoms.models.webhook_subscription_populated import WebhookSubscriptionPopulated

__all__ = [
    # API Classes
    "AgentTemplatesApi",
    "AgentsApi",
    "CallsApi",
    "CampaignsApi",
    "KnowledgeBaseApi",
    "LogsApi",
    "OrganizationApi",
    "UserApi",
    
    # Core Classes
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "AtomsClient",
    
    # Exceptions
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    
    # Agent Models
    "AgentDTO",
    "AgentDTOLanguage",
    "AgentDTOSynthesizer",
    "AgentDTOSynthesizerVoiceConfig",
    "AgentFromTemplatePost200Response",
    "AgentGet200Response",
    "AgentIdDelete200Response",
    "AgentIdGet200Response",
    "AgentIdPatch200Response",
    "AgentIdPatchRequest",
    "AgentIdPatchRequestLanguage",
    "AgentIdPatchRequestSynthesizer",
    "AgentIdPatchRequestSynthesizerVoiceConfig",
    "AgentIdPatchRequestSynthesizerVoiceConfigOneOf",
    "AgentIdPatchRequestSynthesizerVoiceConfigOneOf1",
    "AgentIdWorkflowGet200Response",
    "AgentIdWorkflowGet200ResponseData",
    "AgentIdWorkflowGet200ResponseDataEdgesInner",
    "AgentIdWorkflowGet200ResponseDataEdgesInnerData",
    "AgentIdWorkflowGet200ResponseDataEdgesInnerMarkerEnd",
    "AgentIdWorkflowGet200ResponseDataNodesInner",
    "AgentIdWorkflowGet200ResponseDataNodesInnerData",
    "AgentIdWorkflowGet200ResponseDataNodesInnerDataVariables",
    "AgentIdWorkflowGet200ResponseDataNodesInnerDataVariablesDataInner",
    "AgentIdWorkflowGet200ResponseDataNodesInnerPosition",
    "AgentIdWorkflowGet404Response",
    "AgentTemplateGet200Response",
    "AgentTemplateGet200ResponseDataInner",
    "CreateAgentFromTemplateRequest",
    "CreateAgentRequest",
    "CreateAgentRequestLanguage",
    "CreateAgentRequestLanguageSynthesizer",
    "CreateAgentRequestLanguageSynthesizerVoiceConfig",
    
    # Webhook Models
    "AgentAgentIdWebhookSubscriptionsDelete200Response",
    "AgentAgentIdWebhookSubscriptionsGet200Response",
    "AgentAgentIdWebhookSubscriptionsGet404Response",
    "AgentAgentIdWebhookSubscriptionsPost201Response",
    "AgentAgentIdWebhookSubscriptionsPost400Response",
    "AgentAgentIdWebhookSubscriptionsPostRequest",
    "Webhook",
    "WebhookAgent",
    "WebhookEvent",
    "WebhookGet200Response",
    "WebhookGet200ResponseData",
    "WebhookIdDelete404Response",
    "WebhookPost201Response",
    "WebhookPostRequest",
    "WebhookPostRequestEventsInner",
    "WebhookSubscription",
    "WebhookSubscriptionPopulated",
    
    # Audience Models
    "AudienceGet200Response",
    "AudienceGet200ResponseDataInner",
    "AudienceIdDelete200Response",
    "AudienceIdDelete400Response",
    "AudienceIdGet200Response",
    "AudienceIdGet400Response",
    "AudienceIdGet403Response",
    "AudienceIdGet404Response",
    "AudienceIdMembersDelete200Response",
    "AudienceIdMembersDelete200ResponseData",
    "AudienceIdMembersDeleteRequest",
    "AudienceIdMembersGet200Response",
    "AudienceIdMembersGet200ResponseData",
    "AudienceIdMembersGet200ResponseDataMembersInner",
    "AudienceIdMembersGet400Response",
    "AudienceIdMembersGet500Response",
    "AudienceIdMembersPost200Response",
    "AudienceIdMembersPost200ResponseDataInner",
    "AudienceIdMembersPost200ResponseDataInnerData",
    "AudienceIdMembersPost400Response",
    "AudienceIdMembersPost403Response",
    "AudienceIdMembersPostRequest",
    "AudienceIdMembersSearchGet200Response",
    "AudienceIdMembersSearchGet200ResponseData",
    "AudienceIdMembersSearchGet200ResponseDataSearchInfo",
    "AudienceIdMembersSearchGet400Response",
    "AudienceIdMembersSearchGet500Response",
    "AudiencePost200Response",
    "AudiencePost200ResponseData",
    "AudiencePost400Response",
    
    # Campaign Models
    "CampaignGet200Response",
    "CampaignGet200ResponseData",
    "CampaignGetRequest",
    "CampaignIdGet200Response",
    "CampaignPost201Response",
    "CampaignPostRequest",
    
    # Conversation Models
    "ConversationIdGet200Response",
    "ConversationIdGet200ResponseData",
    "ConversationOutboundPost200Response",
    "ConversationOutboundPost200ResponseData",
    "ConversationOutboundPostRequest",
    
    # Knowledge Base Models
    "KnowledgeBase",
    "KnowledgeBaseItem",
    "KnowledgebaseGet200Response",
    "KnowledgebaseIdGet200Response",
    "KnowledgebaseIdItemsGet200Response",
    "KnowledgebaseIdItemsUploadTextPostRequest",
    "KnowledgebasePost201Response",
    "KnowledgebasePostRequest",
    
    # Organization Models
    "OrganizationGet200Response",
    "OrganizationGet200ResponseData",
    "OrganizationGet200ResponseDataMembersInner",
    "OrganizationGet200ResponseDataSubscription",
    
    # Phone Numbers Models
    "ProductPhoneNumbersGet200Response",
    "ProductPhoneNumbersGet200ResponseDataInner",
    "ProductPhoneNumbersGet200ResponseDataInnerAttributes",
    
    # User Models
    "UserGet200Response",
    "UserGet200ResponseData",
    
    # Error Response Models
    "BadRequestErrorResponse",
    "InternalServerErrorResponse",
    "UnauthorizedErrorReponse",
]